@@ -1,6 +1,8 @@
 from frmf.db_helper import DBHelper
 from frmf.response import abort
 
+db_helper = DBHelper()
+
 
 class Manager:
     _model = None
@@ -72,7 +74,7 @@ class Manager:
     def create(self, data, *args, **kwargs):
         with DBHelper().flush() as db:
             res = self._model(**data)
-            db.session.add(res)
+            db_helper.add(res)
 
         return res
 
@@ -92,25 +94,26 @@ class Manager:
         return obj
 
     def delete(self, targets, multi=False, *args, **kwargs):
-        with DBHelper().flush() as db:
-            if multi:
-                if not isinstance(targets, list):
-                    raise TypeError()
-                for target in targets:
-                    instance = self._model.query.get(target)
-                    if instance:
-                        db.session.delete(instance)
 
-            else:
-                instance = self._model.query.get(targets)
-                db.session.delete(instance)
+        if multi:
+            if not isinstance(targets, list):
+                raise TypeError()
+            for target in targets:
+                instance = self._model.query.get(target)
+                if instance:
+                    db_helper.delete(instance)
+                    db_helper.flush()
+
+        else:
+            instance = self._model.query.get(targets)
+            db_helper.delete(instance)
 
     def delete_by_instance(self, targets, multi=False, *args, **kwargs):
-        with DBHelper().flush() as db:
-            if multi:
-                if not isinstance(targets, list):
-                    raise TypeError()
-                for target in targets:
-                    db.session.delete(target)
-            else:
-                db.session.delete(targets)
+
+        if multi:
+            if not isinstance(targets, list):
+                raise TypeError()
+            for target in targets:
+                db_helper.delete(target)
+        else:
+            db_helper.delete(targets)
